@@ -1,4 +1,5 @@
 from zope.interface import Interface
+from zope.interface import implementer
 from pyramid.exceptions import ConfigurationError
 from functools import partial
 
@@ -17,14 +18,14 @@ def _create_dynamic_interface(name=None, cache=None):
 create_dynamic_interface = partial(_create_dynamic_interface, cache=_cache)
 
 ## utility
-class TinyUtilityMeta(type):
+class ConfiguredObjectMeta(type):
     def __new__(cls, name, base, attrs):
         check_reserved_word(attrs, "_interface")
-        attrs["_interface"] = provided = create_dynamic_interface("I"+name)
-        return type(name, base, attrs)
+        attrs["_interface"] = iface = create_dynamic_interface("I"+name)
+        return implementer(iface)(type(name, base, attrs))
 
-class TinyUtility(object):
-    __metaclass__ = TinyUtilityMeta
+class ConfiguredObject(object):
+    __metaclass__ = ConfiguredObjectMeta
 
     @classmethod
     def from_settings(cls, settings):
@@ -38,10 +39,6 @@ class TinyUtility(object):
             return cls(**params)
         return from_settings
 
-class ValidativeUtility(TinyUtility):
-    def validate(self):
-        raise NotImplementedError
-
 def classname(cls):
     if hasattr(cls, "__classname__"):
         return cls.__classname__
